summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneycalculator.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneycalculator.h')
-rw-r--r--kmymoney2/widgets/kmymoneycalculator.h59
1 files changed, 30 insertions, 29 deletions
diff --git a/kmymoney2/widgets/kmymoneycalculator.h b/kmymoney2/widgets/kmymoneycalculator.h
index 594d6c7..64674a1 100644
--- a/kmymoney2/widgets/kmymoneycalculator.h
+++ b/kmymoney2/widgets/kmymoneycalculator.h
@@ -26,13 +26,13 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qwidget.h>
-#include <qframe.h>
-#include <qlayout.h>
-#include <qgrid.h>
-#include <qlcdnumber.h>
-#include <qlineedit.h>
-#include <qlabel.h>
+#include <tqwidget.h>
+#include <tqframe.h>
+#include <tqlayout.h>
+#include <tqgrid.h>
+#include <tqlcdnumber.h>
+#include <tqlineedit.h>
+#include <tqlabel.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -56,10 +56,11 @@
* without having the user to re-type the data. See setInitialValues()
* for details.
*/
-class kMyMoneyCalculator : public QFrame {
+class kMyMoneyCalculator : public TQFrame {
Q_OBJECT
+ TQ_OBJECT
public:
- kMyMoneyCalculator(QWidget* parent = 0, const char *name = 0);
+ kMyMoneyCalculator(TQWidget* tqparent = 0, const char *name = 0);
~kMyMoneyCalculator();
/**
@@ -67,10 +68,10 @@ public:
* calculation. The fractional part is separated from the
* integral part by the character setup using setComma().
*
* @return QString representing the result of the
* last operation
*/
- const QString result(void) const;
+ const TQString result(void) const;
/**
* This method is used to set the character to be used
@@ -78,9 +79,9 @@ public:
* of an operand. Upon creation of the object, m_comma is
* set to the current locale setting of KDE's decimalSymbol.
*
* @param ch QChar representing the character to be used
*/
- void setComma(const QChar ch) { m_comma = ch; };
+ void setComma(const TQChar ch) { m_comma = ch; };
/**
* This method is used to preset the first operand and start
@@ -88,10 +89,10 @@ public:
* by kMyMoneyEdit. If @p ev is 0, then no operation will be
* started.
*
* @param value reference to QString representing the operands value
* @param ev pointer to QKeyEvent representing the operation's key
*/
- void setInitialValues(const QString& value, QKeyEvent* ev);
+ void setInitialValues(const TQString& value, TQKeyEvent* ev);
signals:
/**
@@ -100,16 +101,16 @@ signals:
void signalResultAvailable();
protected:
- void keyPressEvent(QKeyEvent* ev);
+ void keyPressEvent(TQKeyEvent* ev);
/**
* This method is used to transform a double into a QString
* and removing any trailing 0's and decimal seperators
*
* @param val reference to double value to be converted
* @return QString object containing the converted value
*/
- QString normalizeString(const double& val);
+ TQString normalizeString(const double& val);
protected slots:
/**
@@ -124,7 +125,7 @@ protected slots:
/**
* This methods starts the operation contained in the parameter
*
- * @param button The Qt::Keycode for the button pressed or clicked
+ * @param button The TQt::Keycode for the button pressed or clicked
*/
void calculationClicked(int button);
@@ -158,27 +159,27 @@ protected slots:
* This method updates the display of the calculator with
* the text passed as argument
*
* @param str reference to QString containing the new display contents
*/
- void changeDisplay(const QString& str);
+ void changeDisplay(const TQString& str);
private:
/**
* This member variable stores the current (second) operand
*/
- QString operand;
+ TQString operand;
/**
* This member variable stores the last result
*/
- QString m_result;
+ TQString m_result;
/**
* This member variable stores the representation of the
* character to be used to separate the integer and fractional
* part of numbers. The internal representation is always a period.
*/
- QChar m_comma;
+ TQChar m_comma;
/**
* The numeric representation of a stacked first operand
@@ -204,7 +205,7 @@ private:
/**
* This member stores a pointer to the display area
*/
- QLabel *display;
+ TQLabel *display;
/**
* This member array stores the pointers to the various
@@ -221,7 +222,7 @@ private:
/* 0-9 are used by digits */
COMMA = 10,
/*
* make sure, that PLUS through EQUAL remain in
* the order they are. Otherwise, check the calculation
* signal mapper
*/
@@ -229,7 +230,7 @@ private:
MINUS,
SLASH,
STAR,
- EQUAL,
+ ETQUAL,
PLUSMINUS,
PERCENT,
CLEAR,
@@ -67,10 +68,10 @@ public:
* integral part by the character setup using setComma().
*
- * @return QString representing the result of the
+ * @return TQString representing the result of the
* last operation
*/
@@ -78,9 +79,9 @@ public:
* set to the current locale setting of KDE's decimalSymbol.
*
- * @param ch QChar representing the character to be used
+ * @param ch TQChar representing the character to be used
*/
@@ -88,10 +89,10 @@ public:
* started.
*
- * @param value reference to QString representing the operands value
- * @param ev pointer to QKeyEvent representing the operation's key
+ * @param value reference to TQString representing the operands value
+ * @param ev pointer to TQKeyEvent representing the operation's key
*/
@@ -100,16 +101,16 @@ signals:
/**
- * This method is used to transform a double into a QString
+ * This method is used to transform a double into a TQString
* and removing any trailing 0's and decimal seperators
*
@@ -100,16 +101,16 @@ signals:
*
* @param val reference to double value to be converted
- * @return QString object containing the converted value
+ * @return TQString object containing the converted value
*/
@@ -158,27 +159,27 @@ protected slots:
* the text passed as argument
*
- * @param str reference to QString containing the new display contents
+ * @param str reference to TQString containing the new display contents
*/
@@ -221,7 +222,7 @@ private:
COMMA = 10,
/*
- * make sure, that PLUS through EQUAL remain in
+ * make sure, that PLUS through ETQUAL remain in
* the order they are. Otherwise, check the calculation
* signal mapper